@@ -30,12 +30,12 @@ class SearchDialog : public Dialog {
     SearchDialog (const SearchDialog&) ;
     SearchDialog& operator= (const SearchDialog&) ;
 
-    Gtk::HBox *m_hbox ;
+    Gtk::Box *m_hbox ;
     Gtk::Entry *m_entry ;
     Gtk::Button *m_search_forward_button ;
     Gtk::Button *m_search_backward_button ;
-    sigc::signal<void> m_forward_search_requested_signal ;
-    sigc::signal<void> m_backward_search_requested_signal ;
+    sigc::signal<void()> m_forward_search_requested_signal ;
+    sigc::signal<void()> m_backward_search_requested_signal ;
 
     void init_members ()
     {
@@ -47,9 +47,9 @@ class SearchDialog : public Dialog {
 
     void build_widget ()
     {
-        add_button (Stock::CLOSE, RESPONSE_ACCEPT) ;
+        add_button ("Close", RESPONSE_ACCEPT) ;
 
-        m_hbox = manage (new HBox) ;
+        m_hbox = manage (new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL)) ;
         get_content_area ()->pack_start (*m_hbox) ;
 
         Label *label = manage (new Label ("Search: ")) ;
@@ -68,7 +68,6 @@ class SearchDialog : public Dialog {
                 (*this, &SearchDialog::on_search_backward_button_clicked_signal));
 
         m_hbox->pack_start (*m_search_backward_button, PACK_SHRINK) ;
-        m_hbox->show_all () ;
     }
 
     void on_search_forward_button_clicked_signal ()
@@ -100,12 +99,12 @@ public:
         a_str = m_entry->get_text () ;
     }
 
-    sigc::signal<void>& forward_search_requested_signal ()
+    sigc::signal<void()>& forward_search_requested_signal ()
     {
         return m_forward_search_requested_signal ;
     }
 
-    sigc::signal<void>& backward_search_requested_signal ()
+    sigc::signal<void()>& backward_search_requested_signal ()
     {
         return m_backward_search_requested_signal ;
     }
@@ -125,7 +124,7 @@ class App {
     Menu *m_edit_menu;
     MenuItem *m_edit_menu_item ;
     MenuItem *m_search_menu_item ;
-    VBox *m_main_vbox ;
+    Box *m_main_vbox ;
     View *m_source_view;
 
 public:
@@ -167,8 +166,8 @@ public:
             FileChooserDialog fc_dialog ("open a file",
                                          FILE_CHOOSER_ACTION_OPEN);
             fc_dialog.set_select_multiple (false) ;
-            fc_dialog.add_button (Stock::CANCEL, RESPONSE_CANCEL) ;
-            fc_dialog.add_button (Stock::OK, RESPONSE_ACCEPT) ;
+            fc_dialog.add_button ("Cancel", RESPONSE_CANCEL) ;
+            fc_dialog.add_button ("OK", RESPONSE_ACCEPT) ;
             int res = fc_dialog.run () ;
             if (res != RESPONSE_ACCEPT) {return;}
             ustring filename = fc_dialog.get_filename () ;
@@ -317,7 +316,7 @@ public:
     {
         if (m_main_vbox) {return;}
 
-        m_main_vbox = manage (new VBox) ;
+        m_main_vbox = manage (new Gtk::Box(Gtk::ORIENTATION_VERTICAL)) ;
         g_return_if_fail (m_menu_bar) ;
         m_main_vbox->pack_start (*m_menu_bar, PACK_SHRINK) ;
         m_source_view = manage (new View) ;
@@ -370,7 +369,6 @@ main (int argc, char **argv)
 
     App app ; //TODO: Derive from Gtk::Application?
     app.get_widget ().set_size_request (500, 400) ;
-    app.get_widget ().show_all () ;
     if (argc == 2) {
         app.open_file (filename_to_utf8 (argv[1])) ;
     }
